<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>Cal accés com a Administrador</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Per aquesta operació cal tenir privilegis d&apos;administrador: Si us plau, torneu a arrencar l&apos;aplicació i entreu la vostra contrasenya us la demani.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../src/dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>S&apos;ha detectat un sistema autònom. Si us plau, seleccioneu la partició
arrel del sistema que voleu modificar (només es mostren
particions Linux)</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Usa una estructura de menú simplificada sense submenús</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Usa un menú pla (sense submenús)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Arrenca amb </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Es posa a &quot;0&quot; per arrencar immediatament sense mostrar el menú, o a &quot;-1&quot; per esperar indefinidament.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Temps d&apos;espera del menú</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Paràmetres del kernel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>segons </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Amb aquesta opció activada qualsevol entrada que trieu del menú GRUB es desarà com l&apos;opció per omissió en futures arrencades</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Activa desar la darrera opció arrencada</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Gestiona les opcions d&apos;arrencada UEFI</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Fons de pantalla</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Imatge</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="181"/>
        <location filename="../src/mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Activa el tema</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Pantalla de presentació</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Vista prèvia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Missatges</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Molt detallats</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detallats (opció per omissió)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limitats</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Mostra el registre</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>Still running</source>
        <translation>Encara s&apos;executa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="391"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instal·lant la pantalla de presentació, espereu si us plau</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <location filename="../src/mainwindow.cpp" line="1188"/>
        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
        <translation>La previsualització està desactivada perquè el paràmetre &apos;splash&apos; no està present a la línia d&apos;ordres del kernel. Per activar la previsualització, afegiu &apos;splash&apos; als paràmetres d&apos;arrencada i arrenqueu de nou.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="161"/>
        <location filename="../src/mainwindow.cpp" line="1191"/>
        <source>Preview is disabled while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation>La vista prèvia està desactivada mentre s&apos;executa amb Wayland. Si us plau, inicieu una sessió d&apos;X11 per obtenir una vista prèvia dels temes del Plymouth.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Updating sources</source>
        <translation>Actualitzant les fonts</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <source>Could not install the bootsplash.</source>
        <translation>No he pogut instal·lar la pantalla de presentació.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <source>Could not create a temporary folder</source>
        <translation>No s&apos;ha pogut crear un directori temporal</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <location filename="../src/mainwindow.cpp" line="584"/>
        <source>Cannot continue</source>
        <translation>No puc continuar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>No puc obrir el dispositiu LUKS. Sortint...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="585"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>No puc crear entorn chroot, no es poden canviar les opcions d&apos;arrencada. Sortint...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="917"/>
        <location filename="../src/mainwindow.cpp" line="1315"/>
        <source>Updating configuration, please wait</source>
        <translation>Actualitzant la configuració, espereu si us plau</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="988"/>
        <source>Updating initramfs...</source>
        <translation>Actualitzant initramfs...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1002"/>
        <location filename="../src/mainwindow.cpp" line="1330"/>
        <source>Updating grub...</source>
        <translation>Actualitzant GRUB...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1027"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1028"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1030"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa per seleccionar les opcions d&apos;arrencada usuals</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1032"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1033"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1054"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1064"/>
        <location filename="../src/mainwindow.cpp" line="1292"/>
        <source>Running in a Virtual Machine</source>
        <translation>Executant-se en Màquina Virtual</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1065"/>
        <location filename="../src/mainwindow.cpp" line="1293"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>El vostre sistema actual s&apos;executa en una Màquina Virtual.
La pantalla de presentació Plymouth funcionarà de forma limitada, i tampoc podreu tenir vista prèvia del tema.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1072"/>
        <source>Plymouth packages not installed</source>
        <translation>No s&apos;han instal·lat els paquets de Plymouth</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1073"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Els paquets de Plymouth no estan instal·lats.
Voleu continuar i instal·lar-los?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1099"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imatges (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Log not found</source>
        <translation>No he trobat el registre</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Could not find log at </source>
        <translation>No he trobat el registre a </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1274"/>
        <source>Preview Unavailable</source>
        <translation>Vista prèvia no disponible</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1275"/>
        <source>Preview is not available while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation>La vista prèvia no està disponible mentre s&apos;executa amb Wayland. Si us plau, inicieu una sessió d&apos;X11 per obtenir una vista prèvia dels temes del Plymouth.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>No puc recuperar l&apos;UUID per %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1407"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Entreu la contrasenya per desbloquejar la partició encriptada %1:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>L&apos;entrada de contrasenya cancel·lada o buida per %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Could not open %1 LUKS container</source>
        <translation>No puc obrir el contenidor LUKS %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1242"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="101"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Encara hi ha un procés executant-se. Voleu sortir de debò?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="181"/>
        <source>Live System Detected</source>
        <translation>Detectat Sistema Autònom</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Ara esteu executant un Sistema Autònom. Voleu modificar les opcions d&apos;arrencada pel Sistema Autònom o per un Sistema instal·lat?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Live System</source>
        <translation>Sistema Autònom</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Installed System</source>
        <translation>Sistema Instal·lat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <source>Failed to update package sources.</source>
        <translation>Ha fallat en actualitzar les fonts dels paquets.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="406"/>
        <source>Installing packages:</source>
        <translation>Instal·lant paquets:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Pantalla de presentació instal·lada amb èxit.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <source>Failed to create temporary file.</source>
        <translation>Ha fallat en crear un fitxer temporal.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1010"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Ara esteu executant en mode autònom amb l&apos;opció &apos;toram&apos;. Si us plau, recordeu-vos de desar el fitxer de persistència o remaster, altrament es perdran els canvis.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1012"/>
        <source>Your changes have been successfully applied.</source>
        <translation>S&apos;han aplicat els canvis amb èxit.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1013"/>
        <source>Operation Complete</source>
        <translation>Operació completa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1098"/>
        <source>Select image to display in bootloader</source>
        <translation>Trieu la imatge que es mostrarà a l&apos;arrencada</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1234"/>
        <source>Boot Log</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1281"/>
        <source>Needs reboot</source>
        <translation>Cal reiniciar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1282"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>S&apos;acaba d&apos;instal·lar Plymouth, cal reiniciar abans de poder mostrar la vista prèvia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1355"/>
        <source>Click to select theme</source>
        <translation>Cliqueu per triar el tema</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1366"/>
        <source>Select GRUB theme</source>
        <translation>Trieu el tema del GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa per seleccionar les opcions d&apos;arrencada usuals</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="55"/>
        <location filename="../src/about.cpp" line="64"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
</context>
</TS>